@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone.
+ * This file is part of Liblinphone 
+ * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -32,9 +33,9 @@ extern "C" {
 const char *_get_domain(LinphoneAccountCreator *creator);
 char* _get_identity(const LinphoneAccountCreator *creator);
 unsigned int validate_uri(const char* username, const char* domain, const char* display_name);
-const char* ha1_for_passwd(const char* username, const char* realm, const char* passwd, const char* algo);
 void reset_field (char **field);
 void fill_domain_and_algorithm_if_needed(LinphoneAccountCreator *creator);
+char *generate_random_password(void);
 
 /**
  * @addtogroup account_creator
@@ -150,6 +151,14 @@ LINPHONE_PUBLIC LinphoneAccountCreatorStatus linphone_account_creator_update_acc
 **/
 LINPHONE_PUBLIC LinphoneAccountCreatorStatus linphone_account_creator_login_linphone_account(LinphoneAccountCreator *creator);
 
+/**
+ * Request an auth token to be send by the backend by push notification.
+ * @param creator #LinphoneAccountCreator object @notnil
+ * @return #LinphoneAccountCreatorStatusRequestOk if everything is OK, or a specific error otherwise.
+ **/
+LINPHONE_PUBLIC LinphoneAccountCreatorStatus
+linphone_account_creator_request_auth_token(LinphoneAccountCreator *creator);
+
 /**
  * Acquire a reference to the LinphoneAccountCreator.
  * @param creator #LinphoneAccountCreator object. @notnil
@@ -200,37 +209,61 @@ LINPHONE_PUBLIC LinphoneAccountCreatorUsernameStatus linphone_account_creator_se
 LINPHONE_PUBLIC const char * linphone_account_creator_get_username(const LinphoneAccountCreator *creator);
 
 /**
- * Set the pn_provider.
+ * Set the provider to be used by the backend to send the push notification to the device asking for an auth token.
  * @param creator #LinphoneAccountCreator object @notnil
- * @param pn_provider The pn_provider to set @notnil
- * @return void
+ * @param pn_provider The pn_provider to set @maybenil
 **/
 LINPHONE_PUBLIC void linphone_account_creator_set_pn_provider(LinphoneAccountCreator *creator, const char* pn_provider);
 
 /**
- * Set the pn_param.
+ * Get the provider to be used by the backend to send the push notification to the device asking for an auth token.
  * @param creator #LinphoneAccountCreator object @notnil
- * @param pn_param The pn_param to set @notnil
- * @return void
+ * @return The pn_provider set, if any @maybenil
+**/
+LINPHONE_PUBLIC const char* linphone_account_creator_get_pn_provider(const LinphoneAccountCreator *creator);
+
+/**
+ * Set the param to be used by the backend to send the push notification to the device asking for an auth token.
+ * @param creator #LinphoneAccountCreator object @notnil
+ * @param pn_param The pn_param to set @maybenil
 **/
 LINPHONE_PUBLIC void linphone_account_creator_set_pn_param(LinphoneAccountCreator *creator, const char* pn_param);
 
 /**
- * Set the pn_prid.
+ * Get the param to be used by the backend to send the push notification to the device asking for an auth token.
  * @param creator #LinphoneAccountCreator object @notnil
- * @param pn_prid The pn_prid to set @notnil
- * @return void
+ * @return The pn_param set, if any @maybenil
+**/
+LINPHONE_PUBLIC const char* linphone_account_creator_get_pn_param(const LinphoneAccountCreator *creator);
+
+/**
+ * Set the prid to be used by the backend to send the push notification to the device asking for an auth token.
+ * @param creator #LinphoneAccountCreator object @notnil
+ * @param pn_prid The pn_prid to set @maybenil
 **/
 LINPHONE_PUBLIC void linphone_account_creator_set_pn_prid(LinphoneAccountCreator *creator, const char* pn_prid);
 
 /**
- * Set the token.
+ * Get the prid to be used by the backend to send the push notification to the device asking for an auth token.
  * @param creator #LinphoneAccountCreator object @notnil
- * @param token The pn_prid to set @notnil
- * @return void
+ * @return The pn_prid set, if any @maybenil
+**/
+LINPHONE_PUBLIC const char* linphone_account_creator_get_pn_prid(const LinphoneAccountCreator *creator);
+
+/**
+ * Set the authentication token received by push notification to be used to authenticate next queries, if required.
+ * @param creator #LinphoneAccountCreator object @notnil
+ * @param token The token to set @maybenil
 **/
 LINPHONE_PUBLIC void linphone_account_creator_set_token(LinphoneAccountCreator *creator, const char* token);
 
+/**
+ * Get the authentication token set (if any) to be used to authenticate next queries, if required.
+ * @param creator #LinphoneAccountCreator object @notnil
+ * @return The token set, if any @maybenil
+**/
+LINPHONE_PUBLIC const char* linphone_account_creator_get_token(const LinphoneAccountCreator *creator);
+
 /**
  * Set the phone number normalized.
  * @param creator #LinphoneAccountCreator object @notnil
