@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone.
+ * This file is part of Liblinphone 
+ * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -142,11 +143,12 @@ LINPHONE_PUBLIC void linphone_chat_message_set_content_type (LinphoneChatMessage
  */
 LINPHONE_PUBLIC const char *linphone_chat_message_get_utf8_text (const LinphoneChatMessage* message);
 
-/** Set a chat message text to be sent by linphone_chat_room_send_message(). Introduced in 01/07/2020
+/**
+ * Set a chat message text to be sent by linphone_chat_room_send_message(). Introduced in 01/07/2020
  * @param message #LinphoneChatMessage @notnil
  * @param text The text in UTF8 to set. @maybenil
  * @return 0 if succeed.
-*/
+ */
 LINPHONE_PUBLIC int linphone_chat_message_set_utf8_text(LinphoneChatMessage *message , const char* text);
 
 /**
@@ -352,7 +354,7 @@ LINPHONE_PUBLIC bool_t linphone_chat_message_is_ephemeral(const LinphoneChatMess
  * The lifetime is the duration after which the ephemeral message will disappear once viewed.
  * @see linphone_chat_message_is_ephemeral()
  * @param message #LinphoneChatMessage object. @notnil
- * @return the lifetime of an ephemeral message, by default 86400s.
+ * @return the lifetime of an ephemeral message, by default 0 (disabled).
  */
 LINPHONE_PUBLIC long linphone_chat_message_get_ephemeral_lifetime (const LinphoneChatMessage *message);
 
@@ -456,6 +458,13 @@ LINPHONE_PUBLIC bctbx_list_t *linphone_chat_message_get_participants_by_imdn_sta
  * @return the call Id @notnil
  */
 LINPHONE_PUBLIC const char *linphone_chat_message_get_call_id(const LinphoneChatMessage *message);
+	
+/**
+ * Returns wether the chat message has a conference invitation content or not.
+ * @param message #LinphoneChatMessage object. @notnil
+ * @return TRUE if it has one, FALSE otherwise.
+ */
+LINPHONE_PUBLIC bool_t linphone_chat_message_has_conference_invitation_content (const LinphoneChatMessage *message);
 
 /************ */
 /* DEPRECATED */
@@ -537,13 +546,14 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_set_file_transfer
  */
 LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneChatMessageCbs *linphone_chat_message_get_callbacks (const LinphoneChatMessage *message);
 
-/** Set a chat message text to be sent by linphone_chat_room_send_message()
+/**
+ * Set a chat message text to be sent by linphone_chat_room_send_message()
  * @param message #LinphoneChatMessage @notnil
  * @param text The text is in System Locale. @maybenil
  * @return 0 if succeed.
  * @deprecated 01/07/2020. Use linphone_chat_message_set_utf8_text() instead.
  * @donotwrap
-*/
+ */
 LINPHONE_PUBLIC LINPHONE_DEPRECATED int linphone_chat_message_set_text(LinphoneChatMessage *message , const char* text);
 
 /**
