@@ -81,6 +81,22 @@ typedef LinphoneCoreCbsCallStateChangedCb LinphoneCoreCallStateChangedCb;
  */
 typedef void (*LinphoneCoreCbsCallGoClearAckSentCb)(LinphoneCore *core, LinphoneCall *call);
 
+/**
+ * Call send master key changed callback.
+ * @param core the #LinphoneCore @notnil
+ * @param call the #LinphoneCall on which the GoClear ACK was sent. @notnil
+ * @param master_key new master key. @maybenil
+ */
+typedef void (*LinphoneCoreCbsCallSendMasterKeyChangedCb)(LinphoneCore *core, LinphoneCall *call, const char * master_key);
+
+/**
+ * Call receive master key changed callback.
+ * @param core the #LinphoneCore @notnil
+ * @param call the #LinphoneCall on which the GoClear ACK was sent. @notnil
+ * @param master_key new master key. @maybenil
+ */
+typedef void (*LinphoneCoreCbsCallReceiveMasterKeyChangedCb)(LinphoneCore *core, LinphoneCall *call, const char * master_key);
+
 /**
  * Call encryption changed callback.
  * @param core the #LinphoneCore @notnil
@@ -226,6 +242,18 @@ typedef void (*LinphoneCoreCbsMessageSentCb)(LinphoneCore *core, LinphoneChatRoo
  */
 typedef LinphoneCoreCbsMessageReceivedCb LinphoneCoreMessageReceivedCb;
 
+/**
+ * Chat room session state changed callback
+ * @param core #LinphoneCore object @notnil
+ * @param chat_room #LinphoneChatRoom that has been marked as read. @notnil
+ * @param state the new #LinphoneCallState of the call
+ * @param message a non NULL informational message about the state. @notnil
+ */
+typedef void (*LinphoneCoreCbsChatRoomSessionStateChangedCb)(LinphoneCore *core,
+                                                             LinphoneChatRoom *chat_room,
+                                                             LinphoneCallState state,
+                                                             const char *message);
+
 /**
  * Chat room marked as read callback
  * @param core #LinphoneCore object @notnil
@@ -297,7 +325,7 @@ typedef void (*LinphoneCoreCbsDtmfReceivedCb)(LinphoneCore* core, LinphoneCall *
  */
 typedef LinphoneCoreCbsDtmfReceivedCb LinphoneCoreDtmfReceivedCb;
 
-/** 
+/**
  * Callback prototype for when a refer is received
  * @param core the #LinphoneCore @notnil
  * @param refer_to the address of the refer @notnil
@@ -309,11 +337,11 @@ typedef void (*LinphoneCoreCbsReferReceivedCb)(LinphoneCore *core, const char *r
  */
 typedef LinphoneCoreCbsReferReceivedCb LinphoneCoreReferReceivedCb;
 
-/** 
+/**
  * Callback prototype when using the buddy plugin
  * @param core the #LinphoneCore @notnil
  * @param linphone_friend the #LinphoneFriend that has been updated @notnil
- */ 
+ */
 typedef void (*LinphoneCoreCbsBuddyInfoUpdatedCb)(LinphoneCore *core, LinphoneFriend *linphone_friend);
 
 /**
@@ -412,7 +440,7 @@ typedef void (*LinphoneCoreCbsLogCollectionUploadProgressIndicationCb)(LinphoneC
 typedef LinphoneCoreCbsLogCollectionUploadProgressIndicationCb LinphoneCoreLogCollectionUploadProgressIndicationCb;
 
 /**
- * Callback prototype for reporting when a friend list has been added to the core friends list.
+ * Callback prototype for reporting when a friend list has been added to the core friend lists.
  * @param core #LinphoneCore object @notnil
  * @param friend_list #LinphoneFriendList object @notnil
  */
@@ -424,7 +452,7 @@ typedef void (*LinphoneCoreCbsFriendListCreatedCb) (LinphoneCore *core, Linphone
 typedef LinphoneCoreCbsFriendListCreatedCb LinphoneCoreFriendListCreatedCb;
 
 /**
- * Callback prototype for reporting when a friend list has been removed from the core friends list.
+ * Callback prototype for reporting when a friend list has been removed from the core friend lists.
  * @param core #LinphoneCore object @notnil
  * @param friend_list #LinphoneFriendList object @notnil
  */
@@ -662,8 +690,8 @@ typedef void (*LinphoneFriendListCbsContactUpdatedCb)(LinphoneFriendList *friend
  * Callback used to notify the status of the synchronization has changed
  * @param friend_list The #LinphoneFriendList object for which the status has changed @notnil
  * @param status The new #LinphoneFriendListSyncStatus
- * @param message An additional information on the status update @notnil
-**/
+ * @param message An additional information on the status update @maybenil
+ **/
 typedef void (*LinphoneFriendListCbsSyncStateChangedCb)(LinphoneFriendList *friend_list, LinphoneFriendListSyncStatus status, const char *message);
 
 /**
@@ -673,6 +701,12 @@ typedef void (*LinphoneFriendListCbsSyncStateChangedCb)(LinphoneFriendList *frie
 **/
 typedef void (*LinphoneFriendListCbsPresenceReceivedCb)(LinphoneFriendList *friend_list, const bctbx_list_t *friends);
 
+/**
+ * Callback used to notify a friend that it has received presence information.
+ * @param linphone_friend The #LinphoneFriend object for which the status has changed @notnil
+**/
+typedef void (*LinphoneFriendCbsPresenceReceivedCb)(LinphoneFriend *linphone_friend);
+
 /**
  * @}
 **/
