@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone.
+ * This file is part of Liblinphone 
+ * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -22,6 +23,7 @@
 
 #include "linphone/types.h"
 #include "linphone/sipsetup.h"
+#include "linphone/callbacks.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -76,13 +78,27 @@ LINPHONE_PUBLIC void linphone_friend_remove_address(LinphoneFriend *linphone_fri
  */
 LINPHONE_PUBLIC void linphone_friend_add_phone_number(LinphoneFriend *linphone_friend, const char *phone_number);
 
+/**
+ * Adds a #LinphoneFriendPhoneNumber to this friend
+ * @param linphone_friend #LinphoneFriend object @notnil
+ * @param phone_number the #LinphoneFriendPhoneNumber to add @notnil
+ */
+LINPHONE_PUBLIC void linphone_friend_add_phone_number_with_label(LinphoneFriend *linphone_friend, LinphoneFriendPhoneNumber *phone_number);
+
 /**
  * Returns a list of phone numbers for this friend
  * @param linphone_friend #LinphoneFriend object @notnil
- * @return A list of phone numbers as string. \bctbx_list{const char *} @maybenil @tobefreed
+ * @return A list of phone numbers as string. \bctbx_list{char *} @maybenil @tobefreed
  */
 LINPHONE_PUBLIC bctbx_list_t* linphone_friend_get_phone_numbers(const LinphoneFriend *linphone_friend);
 
+/**
+ * Returns a list of #LinphoneFriendPhoneNumber for this friend
+ * @param linphone_friend #LinphoneFriend object @notnil
+ * @return A list of phone numbers as string. \bctbx_list{LinphoneFriendPhoneNumber} @maybenil @tobefreed
+ */
+LINPHONE_PUBLIC bctbx_list_t* linphone_friend_get_phone_numbers_with_label(const LinphoneFriend *linphone_friend);
+
 /**
  * Returns whether a friend contains the given phone number
  * @param linphone_friend #LinphoneFriend object @notnil
@@ -98,6 +114,13 @@ LINPHONE_PUBLIC bool_t linphone_friend_has_phone_number(const LinphoneFriend *li
  */
 LINPHONE_PUBLIC void linphone_friend_remove_phone_number(LinphoneFriend *linphone_friend, const char *phone_number);
 
+/**
+ * Removes a #LinphoneFriendPhoneNumber from this friend
+ * @param linphone_friend #LinphoneFriend object @notnil
+ * @param phone_number the #LinphoneFriendPhoneNumber to remove @notnil
+ */
+LINPHONE_PUBLIC void linphone_friend_remove_phone_number_with_label(LinphoneFriend *linphone_friend, const LinphoneFriendPhoneNumber *phone_number);
+
 /**
  * Set the display name for this friend
  * @param linphone_friend #LinphoneFriend object @notnil
@@ -355,6 +378,130 @@ LINPHONE_PUBLIC float linphone_friend_get_capability_version(const LinphoneFrien
  */
 LINPHONE_PUBLIC void linphone_friend_remove(LinphoneFriend *linphone_friend);
 
+/**
+ * Sets the contact's picture URI
+ * @param linphone_friend the #LinphoneFriend object.
+ * @param picture_uri the picture URI to set. @maybenil
+ */
+LINPHONE_PUBLIC void linphone_friend_set_photo(LinphoneFriend *linphone_friend, const char *picture_uri);
+
+/**
+ * Gets the contact's picture URI
+ * @param linphone_friend the #LinphoneFriend object.
+ * @return the picture URI set if any, NULL otherwise. @maybenil
+ */
+LINPHONE_PUBLIC const char * linphone_friend_get_photo(const LinphoneFriend *linphone_friend);
+
+/**
+ * Sets if the friend is a user's favorite or important contact.
+ * @param linphone_friend the #LinphoneFriend object.
+ * @param is_starred TRUE if the friend is to be considered as important, FALSE otherwise.
+ */
+LINPHONE_PUBLIC void linphone_friend_set_starred(LinphoneFriend *linphone_friend, bool_t is_starred);
+
+/**
+ * Gets if the friend is to be considered as important for the user.
+ * @param linphone_friend the #LinphoneFriend object.
+ * @return TRUE if the contact is a user's favorite, FALSE otherwise.
+ */
+LINPHONE_PUBLIC bool_t linphone_friend_get_starred(const LinphoneFriend *linphone_friend);
+
+/**
+ * Sets the contact's native URI.
+ * @param linphone_friend the #LinphoneFriend object.
+ * @param native_uri the URI that matches the contact on the native system. @maybenil
+ */
+LINPHONE_PUBLIC void linphone_friend_set_native_uri(LinphoneFriend *linphone_friend, const char *native_uri);
+
+/**
+ * Gets the contact's native URI
+ * @param linphone_friend the #LinphoneFriend object.
+ * @return the native URI set if any, NULL otherwise. @maybenil
+ */
+LINPHONE_PUBLIC const char * linphone_friend_get_native_uri(const LinphoneFriend *linphone_friend);
+
+/**
+ * Sets the contact's organization.
+ * It's a shortcut to linphone_friend_get_vcard() and linphone_vcard_set_organization().
+ * @param linphone_friend the #LinphoneFriend object.
+ * @param organization the organization to store in Friend's vCard. @maybenil
+ */
+LINPHONE_PUBLIC void linphone_friend_set_organization(LinphoneFriend *linphone_friend, const char *organization);
+
+/**
+ * Gets the contact's organization from it's vCard. 
+ * It's a shortcut to linphone_friend_get_vcard() and linphone_vcard_get_organization().
+ * @param linphone_friend the #LinphoneFriend object.
+ * @return the organization set if any & vCard is available, NULL otherwise. @maybenil
+ */
+LINPHONE_PUBLIC const char * linphone_friend_get_organization(const LinphoneFriend *linphone_friend);
+
+/************ */
+/* Friend CBS */
+/* ********** */
+
+/**
+ * Adds the #LinphoneFriendCbs object associated with a LinphoneFriend.
+ * @param linphone_friend #LinphoneFriend object @notnil
+ * @param cbs The current #LinphoneFriendCbs object to be added to the LinphoneFriend. @notnil
+ **/
+LINPHONE_PUBLIC void linphone_friend_add_callbacks(LinphoneFriend *linphone_friend, LinphoneFriendCbs *cbs);
+
+/**
+ * Removes the #LinphoneFriendCbs object associated with a LinphoneFriend.
+ * @param linphone_friend #LinphoneFriend object @notnil
+ * @param cbs The current #LinphoneFriendCbs object to be remove from the LinphoneFriend. @notnil
+ **/
+LINPHONE_PUBLIC void linphone_friend_remove_callbacks(LinphoneFriend *linphone_friend, LinphoneFriendCbs *cbs);
+
+/**
+ * Get the current #LinphoneFriendCbs object associated with a LinphoneFriend.
+ * @param linphone_friend #LinphoneFriend object @notnil
+ * @return The current #LinphoneFriendCbs object associated with the LinphoneFriend. @maybenil
+ **/
+LINPHONE_PUBLIC LinphoneFriendCbs *linphone_friend_get_current_callbacks(const LinphoneFriend *linphone_friend);
+
+/**
+ * Acquire a reference to a #LinphoneFriendCbs object.
+ * @param cbs #LinphoneFriendCbs object. @notnil
+ * @return The same #LinphoneFriendCbs object.
+ **/
+LINPHONE_PUBLIC LinphoneFriendCbs *linphone_friend_cbs_ref(LinphoneFriendCbs *cbs);
+
+/**
+ * Release a reference to a #LinphoneFriendCbs object.
+ * @param cbs #LinphoneFriendCbs object. @notnil
+ **/
+LINPHONE_PUBLIC void linphone_friend_cbs_unref(LinphoneFriendCbs *cbs);
+
+/**
+ * Retrieve the user pointer associated with a #LinphoneFriendCbs object.
+ * @param cbs #LinphoneFriendCbs object. @notnil
+ * @return The user pointer associated with the #LinphoneFriendCbs object. @maybenil
+ **/
+LINPHONE_PUBLIC void *linphone_friend_cbs_get_user_data(const LinphoneFriendCbs *cbs);
+
+/**
+ * Assign a user pointer to a #LinphoneFriendCbs object.
+ * @param cbs #LinphoneFriendCbs object. @notnil
+ * @param user_data The user pointer to associate with the #LinphoneFriendCbs object. @maybenil
+ **/
+LINPHONE_PUBLIC void linphone_friend_cbs_set_user_data(LinphoneFriendCbs *cbs, void *user_data);
+
+/**
+ * Get the presence received callback.
+ * @param cbs #LinphoneFriendCbs object. @notnil
+ * @return The current presence received callback.
+**/
+LINPHONE_PUBLIC LinphoneFriendCbsPresenceReceivedCb linphone_friend_cbs_get_presence_received(const LinphoneFriendCbs *cbs);
+
+/**
+ * Set the presence received callback.
+ * @param cbs #LinphoneFriendCbs object. @notnil
+ * @param cb The presence received callback to be used.
+**/
+LINPHONE_PUBLIC void linphone_friend_cbs_set_presence_received(LinphoneFriendCbs *cbs, LinphoneFriendCbsPresenceReceivedCb cb);
+
 /************ */
 /* DEPRECATED */
 /* ********** */
