@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone.
+ * This file is part of Liblinphone 
+ * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -24,6 +25,7 @@
 #include "ortp/payloadtype.h"
 #include "mediastreamer2/msinterfaces.h"
 #include "mediastreamer2/msvideo.h"
+#include "mediastreamer2/zrtp.h"
 #include "linphone/defs.h"
 
 // For migration purpose.
@@ -185,38 +187,41 @@ typedef enum _LinphoneAccountCreatorTransportStatus {
 **/
 typedef enum _LinphoneAccountCreatorStatus {
 	/** Request status **/
-	LinphoneAccountCreatorStatusRequestOk = 0, /**< Request passed */
-	LinphoneAccountCreatorStatusRequestFailed = 1, /**< Request failed */
+	LinphoneAccountCreatorStatusRequestOk = 0,		  /**< Request passed */
+	LinphoneAccountCreatorStatusRequestFailed = 1,	  /**< Request failed */
 	LinphoneAccountCreatorStatusMissingArguments = 2, /**< Request failed due to missing argument(s) */
 	LinphoneAccountCreatorStatusMissingCallbacks = 3, /**< Request failed due to missing callback(s) */
 
 	/** Account status **/
 	/* Creation */
-	LinphoneAccountCreatorStatusAccountCreated = 4, /**< Account created */
+	LinphoneAccountCreatorStatusAccountCreated = 4,	   /**< Account created */
 	LinphoneAccountCreatorStatusAccountNotCreated = 5, /**< Account not created */
 	/* Existence */
-	LinphoneAccountCreatorStatusAccountExist = 6, /**< Account exist */
+	LinphoneAccountCreatorStatusAccountExist = 6,		   /**< Account exist */
 	LinphoneAccountCreatorStatusAccountExistWithAlias = 7, /**< Account exist with alias */
-	LinphoneAccountCreatorStatusAccountNotExist = 8, /**< Account not exist */
-	LinphoneAccountCreatorStatusAliasIsAccount = 9, /**< Account was created with Alias */
-	LinphoneAccountCreatorStatusAliasExist = 10, /**< Alias exist */
-	LinphoneAccountCreatorStatusAliasNotExist = 11, /**< Alias not exist */
+	LinphoneAccountCreatorStatusAccountNotExist = 8,	   /**< Account not exist */
+	LinphoneAccountCreatorStatusAliasIsAccount = 9,		   /**< Account was created with Alias */
+	LinphoneAccountCreatorStatusAliasExist = 10,		   /**< Alias exist */
+	LinphoneAccountCreatorStatusAliasNotExist = 11,		   /**< Alias not exist */
 	/* Activation */
-	LinphoneAccountCreatorStatusAccountActivated = 12, /**< Account activated */
+	LinphoneAccountCreatorStatusAccountActivated = 12,		  /**< Account activated */
 	LinphoneAccountCreatorStatusAccountAlreadyActivated = 13, /**< Account already activated */
-	LinphoneAccountCreatorStatusAccountNotActivated = 14, /**< Account not activated */
+	LinphoneAccountCreatorStatusAccountNotActivated = 14,	  /**< Account not activated */
 	/* Linking */
-	LinphoneAccountCreatorStatusAccountLinked = 15, /**< Account linked */
+	LinphoneAccountCreatorStatusAccountLinked = 15,	   /**< Account linked */
 	LinphoneAccountCreatorStatusAccountNotLinked = 16, /**< Account not linked */
 
 	/** Server **/
-	LinphoneAccountCreatorStatusServerError = 17, /**< Error server */
+	LinphoneAccountCreatorStatusServerError = 17,		  /**< Error server */
 
-	LinphoneAccountCreatorStatusPhoneNumberInvalid = 18, /**< Error cannot send SMS */
+	LinphoneAccountCreatorStatusPhoneNumberInvalid = 18,  /**< Error cannot send SMS */
 	LinphoneAccountCreatorStatusWrongActivationCode = 19, /**< Error key doesn't match */
 	LinphoneAccountCreatorStatusPhoneNumberOverused = 20, /**< Error too many SMS sent */
-	LinphoneAccountCreatorStatusAlgoNotSupported = 21, /**< Error algo isn't MD5 or SHA-256 */
-	LinphoneAccountCreatorStatusUnexpectedError = 22, /**< Generic error */
+	LinphoneAccountCreatorStatusAlgoNotSupported = 21,	  /**< Error algo isn't MD5 or SHA-256 */
+	LinphoneAccountCreatorStatusUnexpectedError = 22,	  /**< Generic error */
+	LinphoneAccountCreatorStatusNotImplementedError = 23, /**< This API isn't implemented in the current backend */
+	LinphoneAccountCreatorStatusRequestNotAuthorized =
+		24, /**< Request has been denied, probably due to invalid auth token */
 } LinphoneAccountCreatorStatus;
 
 // -----------------------------------------------------------------------------
@@ -286,6 +291,17 @@ typedef enum _LinphoneRecorderState {
 	LinphoneRecorderRunning /**< The recorder is running. */
 } LinphoneRecorderState;
 
+/**
+ * @brief Enum representing the type of a video source.
+ * @ingroup call_control
+**/
+typedef enum _LinphoneVideoSourceType {
+	LinphoneVideoSourceUnknown,
+	LinphoneVideoSourceCall, /**< The video source is another call. */
+	LinphoneVideoSourceCamera, /**< The video source is a camera. */
+	LinphoneVideoSourceImage /**< The video source is an image. */
+} LinphoneVideoSourceType;
+
 // -----------------------------------------------------------------------------
 // Friends.
 // -----------------------------------------------------------------------------
@@ -304,6 +320,12 @@ typedef enum _LinphoneRecorderState {
  */
 typedef struct _LinphoneFriend LinphoneFriend;
 
+/**
+ * @brief An object to handle the callbacks for #LinphoneFriend.
+ * @ingroup buddy_list
+ **/
+typedef struct _LinphoneFriendCbs LinphoneFriendCbs;
+
 /**
 * @brief Enum describing the capabilities of a #LinphoneFriend, populated through presence subscribe/notify process.
 * @ingroup buddy_list
@@ -328,6 +350,7 @@ typedef struct _LinphoneFriendList LinphoneFriendList;
  * @ingroup buddy_list
  */
 typedef enum _LinphoneFriendListType {
+	LinphoneFriendListTypeDefault = -1,
 	LinphoneFriendListTypeCardDAV = 0,
 	LinphoneFriendListTypeVCard4 = 1
 } LinphoneFriendListType;
@@ -511,16 +534,6 @@ typedef struct _LinphoneVideoActivationPolicy LinphoneVideoActivationPolicy;
  */
 typedef struct _LinphoneVideoDefinition LinphoneVideoDefinition;
 
-/**
- * @brief Describes conference invitations possible errors.
- *
- * It is notified via the conference_info_on_participant_error() callback in #LinphoneCoreCbs.
- * @ingroup misc
-**/
-typedef enum _LinphoneConferenceInfoError {
-	LinphoneConferenceInfoChatRoomError = 0, /**< Could not create or retrieve chat room */
-} LinphoneConferenceInfoError;
-
 // -----------------------------------------------------------------------------
 // Other.
 // -----------------------------------------------------------------------------
@@ -729,11 +742,11 @@ typedef enum _LinphoneCoreLogCollectionUploadState {
  * @ingroup call_control
  */
 typedef enum _LinphoneMediaDirection {
-	LinphoneMediaDirectionInvalid = -1,
-	LinphoneMediaDirectionInactive = 0, /** No active media not supported yet*/
-	LinphoneMediaDirectionSendOnly = 1, /** Send only mode*/
-	LinphoneMediaDirectionRecvOnly = 2, /** recv only mode*/
-	LinphoneMediaDirectionSendRecv = 3, /** send receive*/
+	LinphoneMediaDirectionInvalid = -1, /**< Default value, shouldn't be used */
+	LinphoneMediaDirectionInactive = 0, /**< No active media not supported yet*/
+	LinphoneMediaDirectionSendOnly = 1, /**< Media is only being sent, it won't be received*/
+	LinphoneMediaDirectionRecvOnly = 2, /**< Media will only be received, nothing will be sent*/
+	LinphoneMediaDirectionSendRecv = 3, /**< Media will be sent and received*/
 } LinphoneMediaDirection;
 
 /**
@@ -756,6 +769,22 @@ typedef enum _LinphoneMediaEncryption {
 	LinphoneMediaEncryptionDTLS = 3 /**< Use DTLS media encryption */
 } LinphoneMediaEncryption;
 
+/**
+ * @brief Enum describing type of SRTP encryption suite
+ * @ingroup media_parameters
+**/
+typedef enum _LinphoneSrtpSuite {
+	LinphoneSrtpSuiteAESCM128HMACSHA180 = 0,
+	LinphoneSrtpSuiteAESCM128HMACSHA132 = 1,
+	LinphoneSrtpSuiteAES192CMHMACSHA180 = 2,
+	LinphoneSrtpSuiteAES192CMHMACSHA132 = 3,
+	LinphoneSrtpSuiteAES256CMHMACSHA180 = 4,
+	LinphoneSrtpSuiteAES256CMHMACSHA132 = 5,
+	LinphoneSrtpSuiteAEADAES128GCM = 6,
+	LinphoneSrtpSuiteAEADAES256GCM = 7,
+	LinphoneSrtpSuiteInvalid = 0xFF
+} LinphoneSrtpSuite;
+
 /**
  * @brief Enum describing the ZRTP SAS validation status of a peer URI.
  * @ingroup media_parameters
@@ -766,6 +795,35 @@ typedef enum _LinphoneZrtpPeerStatus {
 	LinphoneZrtpPeerStatusValid = 2 /**< Peer URI SAS validated in database */
 } LinphoneZrtpPeerStatus;
 
+/**
+ * @brief Enum describing the ZRTP key exchange algorithns
+ * @ingroup media_parameters
+ **/
+typedef enum _LinphoneZrtpKeyAgreement {
+	LinphoneZrtpKeyAgreementInvalid = 0,
+	LinphoneZrtpKeyAgreementDh2k = 1,
+	LinphoneZrtpKeyAgreementDh3k = 2,
+	LinphoneZrtpKeyAgreementEc25 = 3,
+	LinphoneZrtpKeyAgreementEc38 = 4,
+	LinphoneZrtpKeyAgreementEc52 = 5,
+	LinphoneZrtpKeyAgreementX255 = 6,
+	LinphoneZrtpKeyAgreementX448 = 7,
+	LinphoneZrtpKeyAgreementK255 = 8,
+	LinphoneZrtpKeyAgreementK448 = 9,
+	LinphoneZrtpKeyAgreementKyb1 = 10,
+	LinphoneZrtpKeyAgreementKyb2 = 11,
+	LinphoneZrtpKeyAgreementKyb3 = 12,
+	LinphoneZrtpKeyAgreementHqc1 = 13,
+	LinphoneZrtpKeyAgreementHqc2 = 14,
+	LinphoneZrtpKeyAgreementHqc3 = 15,
+	LinphoneZrtpKeyAgreementK255Kyb512 = 16,
+	LinphoneZrtpKeyAgreementK255Hqc128 = 17,
+	LinphoneZrtpKeyAgreementK448Kyb1024 = 18,
+	LinphoneZrtpKeyAgreementK448Hqc256 = 19,
+	LinphoneZrtpKeyAgreementK255Kyb512Hqc128 = 20,
+	LinphoneZrtpKeyAgreementK448Kyb1024Hqc256 = 21
+} LinphoneZrtpKeyAgreement;
+
 /**
  * @brief Policy to use to pass through NATs/firewalls.
  * @ingroup network_parameters
@@ -777,19 +835,20 @@ typedef struct _LinphoneNatPolicy LinphoneNatPolicy;
  * @deprecated 03/02/2017 Use #LinphonePresenceModel and #LinphonePresenceActivity instead
  * @donotwrap
  */
-typedef enum _LinphoneOnlineStatus{
-	LinphoneStatusOffline = 0, /**< Offline */
-	LinphoneStatusOnline = 1, /**< Online */
-	LinphoneStatusBusy = 2, /**< Busy */
-	LinphoneStatusBeRightBack = 3, /**< Be right back */
-	LinphoneStatusAway = 4, /**< Away */
-	LinphoneStatusOnThePhone = 5, /** On the phone */
-	LinphoneStatusOutToLunch = 6, /**< Out to lunch */
+typedef enum _LinphoneOnlineStatus {
+	LinphoneStatusOffline = 0,		/**< Offline */
+	LinphoneStatusOnline = 1,		/**< Online */
+	LinphoneStatusBusy = 2,			/**< Busy */
+	LinphoneStatusBeRightBack = 3,	/**< Be right back */
+	LinphoneStatusAway = 4,			/**< Away */
+	LinphoneStatusOnThePhone = 5,	/**< On the phone */
+	LinphoneStatusOutToLunch = 6,	/**< Out to lunch */
 	LinphoneStatusDoNotDisturb = 7, /**< Do not disturb */
-	LinphoneStatusMoved = 8, /**< Moved in this sate, call can be redirected if an alternate contact address has been set using function linphone_core_set_presence_info() */
+	LinphoneStatusMoved = 8, /**< Moved in this sate, call can be redirected if an alternate contact address has been
+								set using function linphone_core_set_presence_info() */
 	LinphoneStatusAltService = 9, /**< Using another messaging service */
-	LinphoneStatusPending = 10, /**< Pending */
-	LinphoneStatusVacation = 11, /**< Vacation */
+	LinphoneStatusPending = 10,	  /**< Pending */
+	LinphoneStatusVacation = 11,  /**< Vacation */
 
 	LinphoneStatusEnd = 12
 } LinphoneOnlineStatus;
@@ -1144,12 +1203,13 @@ typedef enum _LinphoneSubscriptionState{
  * @ingroup misc
 **/
 typedef enum _LinphoneToneID {
-	LinphoneToneUndefined = 0, /**< Not a tone */
-	LinphoneToneBusy = 1, /**< Busy tone */
-	LinphoneToneCallWaiting = 2, /** Call waiting tone */
-	LinphoneToneCallOnHold = 3, /** Call on hold tone */
-	LinphoneToneCallLost = 4, /** Tone played when call is abruptly disconnected (media lost)*/
-	LinphoneToneCallEnd = 5 /** When the call end for any reason but lost */
+	LinphoneToneUndefined = 0,	/**< Not a tone */
+	LinphoneToneBusy = 1,		/**< Busy tone */
+	LinphoneToneCallWaiting = 2,	/**< Call waiting tone */
+	LinphoneToneCallOnHold = 3,	/**< Call on hold tone */
+	LinphoneToneCallLost = 4,	/**< Tone played when call is abruptly disconnected (media lost)*/
+	LinphoneToneCallEnd = 5,	/**< When the call end for any reason but lost */
+	LinphoneToneCallNotAnswered = 6	/**< When the call is not answered */
 } LinphoneToneID;
 
 /**
@@ -1326,6 +1386,7 @@ typedef enum _LinphoneMagicSearchSource {
 	LinphoneMagicSearchSourceLdapServers = 1 << 2, /**< Search in LDAP servers */
 	LinphoneMagicSearchSourceChatRooms = 1 << 3, /**< Search in Chat rooms participants */
 	LinphoneMagicSearchSourceRequest = 1 << 4, /**< Search from request : it is usually an address built from the request */
+	LinphoneMagicSearchSourceFavoriteFriends = 1 << 5, /**< Search in "starred" friends only */
 	LinphoneMagicSearchSourceAll = -1 /**< Search in all sources */
 } LinphoneMagicSearchSource;
 
